TokenCharCode

Type Alias TokenCharCode 

pub type TokenCharCode = u32;
Represents the numeric Unicode scalar value (char) of a token’s character.

Each character in a token is converted to its corresponding Unicode scalar value (char), which is stored as a u32. This type is used for better semantic clarity in representing character codes of tokens.